==> cspace-ui-0.11.6.tgz: package/src/plugins/recordTypes/pottag/fields.js <==
import { defineMessages } from 'react-intl';

export default (pluginContext) => {
  const {
    CompoundInput,
    DateInput,
    OptionPickerInput,
    TextInput,
    AutocompleteInput,
    // IDGeneratorInput,
    // TermPickerInput,
    // StructuredDateInput,
    // URLInput,
  } = pluginContext.inputComponents;

  const {
    configKey: config,
  } = pluginContext.configHelpers;

  const {
    DATA_TYPE_DATETIME,
    // DATA_TYPE_FLOAT,
    DATA_TYPE_INT,
  } = pluginContext.dataTypes;

  return {
    document: {
      [config]: {
        view: {
          type: CompoundInput,
          props: {
            defaultChildSubpath: 'ns2:pottags_common',
          },
        },
      },
      // TODO: Define core fields in one place.
      'ns2:collectionspace_core': {
        createdAt: {
          [config]: {
            dataType: DATA_TYPE_DATETIME,
            view: {
              type: DateInput,
            },
          },
        },
        createdBy: {
          [config]: {
            view: {
              type: TextInput,
            },
          },
        },
        updatedAt: {
          [config]: {
            dataType: DATA_TYPE_DATETIME,
            messages: defineMessages({
              name: {
                id: 'field.collectionspace_core.updatedAt.name',
                defaultMessage: 'Last updated time',
              },
            }),
            view: {
              type: DateInput,
            },
          },
        },
        updatedBy: {
          [config]: {
            messages: defineMessages({
              name: {
                id: 'field.collectionspace_core.updatedBy.name',
                defaultMessage: 'Last updated by',
              },
            }),
            view: {
              type: TextInput,
            },
          },
        },
      },
      'ns2:pottags_common': {
        [config]: {
          service: {
            ns: 'http://collectionspace.org/services/pottag',
          },
        },
        taxonName: {
          [config]: {
            messages: defineMessages({
              name: {
                id: 'field.pottags_common.taxonName.name',
                defaultMessage: 'Taxon',
              },
            }),
            view: {
              type: AutocompleteInput,
              props: {
                source: 'taxon/local',
              },
            },
          },
        },
        family: {
          [config]: {
            messages: defineMessages({
              name: {
                id: 'field.pottags_common.family.name',
                defaultMessage: 'Family',
              },
            }),
            view: {
              type: AutocompleteInput,
              props: {
                source: 'taxon/local',
              },
            },
          },
        },
        commonName: {
          [config]: {
            messages: defineMessages({
              name: {
                id: 'field.pottags_common.commonName.name',
                defaultMessage: 'Common Name',
              },
            }),
            view: {
              type: TextInput,
            },
          },
        },
        locale: {
          [config]: {
            messages: defineMessages({
              name: {
                id: 'field.pottags_common.local.name',
                defaultMessage: 'Locale',
              },
            }),
            view: {
              type: TextInput,
            },
          },
        },
        labelData: {
          [config]: {
            messages: defineMessages({
              name: {
                id: 'field.pottags_common.labelData.name',
                defaultMessage: 'Label data',
              },
            }),
            view: {
              type: TextInput,
              props: {
                multiline: true,
              },
            },
          },
        },
        numberOfLabels: {
          [config]: {
            dataType: DATA_TYPE_INT,
            messages: defineMessages({
              name: {
                id: 'field.pottags_common.numberOfLabels.name',
                defaultMessage: 'Number of labels',
              },
            }),
            view: {
              type: TextInput,
            },
          },
        },
        printLabels: {
          [config]: {
            messages: defineMessages({
              name: {
                id: 'field.pottags_common.printLabels.name',
                defaultMessage: 'Print labels',
              },
            }),
            view: {
              type: OptionPickerInput,
              props: {
                source: 'printLabelOptions',
              },
            },
          },
        },
      },
    },
  };
};

==> cspace-ui-0.13.15.tgz: package/src/plugins/recordTypes/pottag/fields.js <==
import { defineMessages } from 'react-intl';
import getCoreFields from '../../../helpers/coreFields';

export default (pluginContext) => {
  const {
    CompoundInput,
    OptionPickerInput,
    TextInput,
    AutocompleteInput,
  } = pluginContext.inputComponents;

  const {
    configKey: config,
  } = pluginContext.configHelpers;

  const {
    DATA_TYPE_INT,
  } = pluginContext.dataTypes;

  const coreFields = getCoreFields(pluginContext);

  return {
    document: {
      [config]: {
        view: {
          type: CompoundInput,
          props: {
            defaultChildSubpath: 'ns2:pottags_common',
          },
        },
      },
      // Define core fields
      ...coreFields,
      'ns2:pottags_common': {
        [config]: {
          service: {
            ns: 'http://collectionspace.org/services/pottag',
          },
        },
        family: {
          [config]: {
            messages: defineMessages({
              name: {
                id: 'field.pottags_common.family.name',
                defaultMessage: 'Family',
              },
            }),
            view: {
              type: AutocompleteInput,
              props: {
                source: 'taxon/local',
              },
            },
          },
        },
        commonName: {
          [config]: {
            messages: defineMessages({
              name: {
                id: 'field.pottags_common.commonName.name',
                defaultMessage: 'Common name',
              },
            }),
            view: {
              type: TextInput,
            },
          },
        },
        locale: {
          [config]: {
            messages: defineMessages({
              name: {
                id: 'field.pottags_common.locale.name',
                defaultMessage: 'Country name/locale',
              },
            }),
            view: {
              type: TextInput,
            },
          },
        },
        taxonName: {
          [config]: {
            messages: defineMessages({
              name: {
                id: 'field.pottags_common.taxonName.name',
                defaultMessage: 'Taxon name',
              },
            }),
            view: {
              type: AutocompleteInput,
              props: {
                source: 'taxon/local',
              },
            },
          },
        },
        labelData: {
          [config]: {
            messages: defineMessages({
              name: {
                id: 'field.pottags_common.labelData.name',
                defaultMessage: 'Label data',
              },
            }),
            view: {
              type: TextInput,
              props: {
                multiline: true,
              },
            },
          },
        },
        numberOfLabels: {
          [config]: {
            dataType: DATA_TYPE_INT,
            messages: defineMessages({
              name: {
                id: 'field.pottags_common.numberOfLabels.name',
                defaultMessage: 'Number of labels',
              },
            }),
            view: {
              type: TextInput,
            },
          },
        },
        printLabels: {
          [config]: {
            messages: defineMessages({
              name: {
                id: 'field.pottags_common.printLabels.name',
                defaultMessage: 'Print labels',
              },
            }),
            view: {
              type: OptionPickerInput,
              props: {
                source: 'printLabelOptions',
              },
            },
          },
        },
      },
    },
  };
};
